/*
  The MIT License (MIT)

  Copyright (c) 2016 Christoffer Hjalmarsson

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NON INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#ifndef INCLUDED_MUSES_72320
#define INCLUDED_MUSES_72320

#include <Arduino.h>

class Muses72320
{
public:
	// contextual data types.
	typedef uint8_t pin_t;
	typedef uint16_t data_t;
	typedef int volume_t;
	typedef uint16_t address_t;
	

	// specify a connection over an address using three output pins.
	Muses72320(address_t chip_address);

	// set the pins in their correct states.
	void begin();

	// set the volume using the following formula:
	//   (-0.25 * volume) db
	// audio level goes from [-117.5, 0.0] dB
	// input goes from -472 to 0.
	void setVolume(volume_t left, volume_t right);
	

	// Gain is disable, this function just set the settings in the gain address
	void setGain();
	

  	void mute();
	//Enable or Disable External Clock. If no external clock is connected this must be set to
	//false
	void setExternalClock(bool enabled);

	// enable or disable zero crossing.
	void setZeroCrossingOn(bool enabled);

	//If set to true Left and Right will not be treated independently
	//To set attenuation with link channels, just set the left channel
	void setLinkChannels(bool enabled);

	


private:
  void transfer(address_t address, data_t data);

private:
	// for multiple chips on the same bus line.
	address_t chip_address;
	data_t states ;
	data_t gain ;
	
};

#endif // INCLUDED_MUSES_72320
